using ProjectAirline.Repositories.Implementations;
using ProjectAirline.Repositories;
using Unity;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Configuration;
using Serilog;
using Unity.Microsoft.Logging;
using Unity.Lifetime;
namespace ProjectAirline
{
    internal static class Program
    {
        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            Application.Run(CreateContainer().Resolve<FormAirline>());
        }

        private static IUnityContainer CreateContainer()
        {
            var container = new UnityContainer();
            container.AddExtension(new LoggingExtension(CreateLoggerFactory()));

            container.RegisterType<IConnectionString, ConnectionString>(new SingletonLifetimeManager());

            container.RegisterType<IFlightRepository, FlightRepository>(new TransientLifetimeManager());
            container.RegisterType<IPassengerRepository, PassengerRepository>(new TransientLifetimeManager());
            container.RegisterType<IAirplaneRepository, AirplaneRepository>(new TransientLifetimeManager());
            container.RegisterType<IEmployeeFlightRepository, EmployeeFlightRepository>(new TransientLifetimeManager());
            container.RegisterType<IEmployeeRepository, EmployeeRepository>(new TransientLifetimeManager());
            container.RegisterType<ITicketRepository, TicketRepository>(new TransientLifetimeManager());


            return container;
        }

        private static LoggerFactory CreateLoggerFactory()
        {
            var loggerFactory = new LoggerFactory();
            loggerFactory.AddSerilog(new LoggerConfiguration()
            .ReadFrom.Configuration(new ConfigurationBuilder()
                .SetBasePath(Directory.GetCurrentDirectory())
                .AddJsonFile("appsettings.json")
                .Build())
            .CreateLogger());
            return loggerFactory;
        }
    }
}