﻿using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using ProjectAirline.Entities;
using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectAirline.Repositories.Implementations;

public class AirplaneRepository : IAirplaneRepository
{
    private readonly IConnectionString _connectionString;

    private readonly ILogger<AirplaneRepository> _logger;

    public AirplaneRepository(IConnectionString connectionString, ILogger<AirplaneRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    } 
    public void CreateAirplane(Airplane airplane)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}", JsonConvert.SerializeObject(airplane));
        try
        {
            using var connection = new NpgsqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"INSERT INTO Airplane (Country, Model, Capacity) 
                VALUES (@Country, @Model, @Capacity)";
            connection.Execute(queryInsert, airplane);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }

    }
    public void UpdateAirplane(Airplane airplane)
        {
            _logger.LogInformation("Редактирование объекта");
            _logger.LogDebug("Объект: {json}",
            JsonConvert.SerializeObject(airplane));
            try
            {
                using var connection = new
                NpgsqlConnection(_connectionString.ConnectionString);
                var queryUpdate = @"
                UPDATE Airplane
                SET
                    Country=@Country,
                    Model=@Model,
                    Capacity=@Capacity
                WHERE Id=@Id";
                connection.Execute(queryUpdate, airplane);
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка при редактировании объекта");
                throw;
            }
    }
    public void DeleteAirplane(int id)
    {
        _logger.LogInformation("Удаление объекта");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryDelete = @"
                DELETE FROM Airplane
                WHERE Id=@id";
            connection.Execute(queryDelete, new { id });
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при удалении объекта");
            throw;
        }
    }


    public Airplane ReadAirplaneById(int id)
    {
        _logger.LogInformation("Получение объекта по идентификатору");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = @"
            SELECT * FROM Airplane
            WHERE Id=@id";
            var airplane = connection.QueryFirst<Airplane>(querySelect, new
            {
                id
            });
            _logger.LogDebug("Найденный объект: {json}",
            JsonConvert.SerializeObject(airplane));
            return airplane;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при поиске объекта");
            throw;
        }

    }

    public IEnumerable<Airplane> ReadAirplanes()
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = "SELECT * FROM Airplane";
            var airplanes = connection.Query<Airplane>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(airplanes));
            return airplanes;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }

    }


}
