﻿using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using ProjectAirline.Entities;
using ProjectAirline.Entities.Enums;
using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectAirline.Repositories.Implementations;

public class EmployeeRepository : IEmployeeRepository
{
    private readonly IConnectionString _connectionString;
    private readonly ILogger<EmployeeRepository> _logger;

    public EmployeeRepository(IConnectionString connectionString, ILogger<EmployeeRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }

    public void CreateEmployee(Employee employee)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(employee));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"
INSERT INTO Employee (FirstName, LastName, ContactInformation, EmployeePost)
VALUES (@FirstName, @LastName, @ContactInformation, @EmployeePost)";
            connection.Execute(queryInsert, employee);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }
    }
    public void UpdateEmployee(Employee employee)
    {
        _logger.LogInformation("Редактирование объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(employee));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryUpdate = @"
UPDATE Employee
SET
FirstName=@FirstName,
LastName=@LastName,
ContactInformation=@ContactInformation,
EmployeePost=@EmployeePost
WHERE Id=@Id";
            connection.Execute(queryUpdate, employee);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при редактировании объекта");
            throw;
        }

    }
    public void DeleteEmployee(int id)
    {
        _logger.LogInformation("Удаление объекта");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryDelete = @"
                DELETE FROM Employee
                WHERE Id=@id";
            connection.Execute(queryDelete, new { id });
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при удалении объекта");
            throw;
        }
    }


    public Employee ReadEmployeeById(int id)
    {
        _logger.LogInformation("Получение объекта по идентификатору");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = @"
SELECT * FROM Employee
WHERE Id=@id";
            var employee = connection.QueryFirst<Employee>(querySelect,
            new { id });
            _logger.LogDebug("Найденный объект: {json}",
            JsonConvert.SerializeObject(employee));
            return employee;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при поиске объекта");
            throw;
        }
    }

    public IEnumerable<Employee> ReadEmployees()
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = "SELECT * FROM Employee";
            var employees = connection.Query<Employee>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(employees));
            return employees;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }
    }

    
}
