﻿using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using ProjectAirline.Entities;
using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectAirline.Repositories.Implementations;

public class FlightRepository : IFlightRepository
{
    private readonly IConnectionString _connectionString;
    private readonly ILogger<FlightRepository> _logger;
    public FlightRepository(IConnectionString connectionString,
    ILogger<FlightRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }

    public void CreateFlight(Flight flight)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(flight));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            connection.Open();
            using var transaction = connection.BeginTransaction();
            var queryInsert = @"
INSERT INTO Flight (AirplaneID, DepartureTime, ArrivalTime, Destination, DeparturePoint, TicketPrice)
VALUES (@AirplaneID, @DepartureTime, @ArrivalTime, @Destination, @DeparturePoint, @TicketPrice);
SELECT MAX(Id) FROM Flight";
            var flightId =
            connection.QueryFirst<int>(queryInsert, flight, transaction);
            var querySubInsert = @"
INSERT INTO EmployeeFlights (EmployeeId, FlightId, HoursWorked)
VALUES (@EmployeeId,@FlightId, @HoursWorked)";
            foreach (var elem in flight.EmployeeFlights)
            {
                connection.Execute(querySubInsert, new
                {
                    elem.EmployeeId,
                    flightId,
                    elem.HoursWorked
                }, transaction);
            }
            transaction.Commit();
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }
    }

    public void DeleteFlight(int id)
    {
        _logger.LogInformation("Удаление объекта");
        _logger.LogDebug("Объект: {id}", id);
        
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryDelete = @"
DELETE FROM Flight
WHERE ID = @id";
            connection.Execute(queryDelete, new { id });
        }

        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при удалении объекта");
            throw;
        }
    }


    public IEnumerable<Flight> ReadFlights(DateTime? dateForm = null, DateTime? dateTo = null, int? flightId = null, int? airplaneId = null)
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = @"SELECT * FROM Flight";
            var flights =
            connection.Query<Flight>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(flights));
            return flights;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }
    }
}
