﻿using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using ProjectAirline.Entities;
using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectAirline.Repositories.Implementations;

public class PassengerRepository : IPassengerRepository
{

    private readonly IConnectionString _connectionString;
    private readonly ILogger<PassengerRepository> _logger;
    public PassengerRepository(IConnectionString connectionString,
    ILogger<PassengerRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }

    public void CreatePassenger(Passenger passenger)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(passenger));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"
INSERT INTO Passenger (FoodPreferences, FirstName, LastName, DateBirth)
VALUES (@FoodPreferences, @FirstName, @LastName, @DateBirth)";
            connection.Execute(queryInsert, passenger);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }
    }
    public void UpdatePassenger(Passenger passenger)
    {
        _logger.LogInformation("Редактирование объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(passenger));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryUpdate = @"
UPDATE Passenger
SET
FoodPreferences=@FoodPreferences,
FirstName=@FirstName,
LastName=@LastName,
DateBirth=@DateBirth
WHERE Id=@Id";
            connection.Execute(queryUpdate, passenger);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при редактировании объекта");
            throw;
        }
    }
    public void DeletePassenger(int id)
    {
        _logger.LogInformation("Удаление объекта");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryDelete = @"
                DELETE FROM Passenger
                WHERE Id=@id";
            connection.Execute(queryDelete, new { id });
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при удалении объекта");
            throw;
        }
    }

    public Passenger ReadPassengerById(int id)
    {
        _logger.LogInformation("Получение объекта по идентификатору");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = @"
SELECT * FROM Passenger
WHERE Id=@id";
            var passenger = connection.QueryFirst<Passenger>(querySelect, new
            {
                id
            });
            _logger.LogDebug("Найденный объект: {json}",
            JsonConvert.SerializeObject(passenger));
            return passenger;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при поиске объекта");
            throw;
        }
    }

    public IEnumerable<Passenger> ReadPassengers()
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = "SELECT * FROM Passenger";
            var passengers = connection.Query<Passenger>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(passengers));
            return passengers;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }
    }

    
}
