﻿using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using ProjectAirline.Entities;
using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectAirline.Repositories.Implementations;

public class TicketRepository : ITicketRepository
{
    private readonly IConnectionString _connectionString;
    private readonly ILogger<TicketRepository> _logger;
    public TicketRepository(IConnectionString connectionString,
    ILogger<TicketRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }

    public void CreateTicket(Ticket ticket)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(ticket));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"
INSERT INTO Ticket (FlightID, PassengerID, TicketPrice, DateBuy)
VALUES (@FlightID, @PassengerID, @TicketPrice, @DateBuy)";
            connection.Execute(queryInsert, ticket);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }
    }

    public IEnumerable<Ticket> ReadTickets()
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = "SELECT * FROM Ticket";
            var tickets =
            connection.Query<Ticket>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(tickets));
            return tickets;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }
    }

}
